<?php
/**
 * ------------------------------------------------------------------------
 * BlueMind Stats Portal, aka bm-stats
 * ------------------------------------------------------------------------
 * @license : GNU Affero General Public License Version 3 <http://www.gnu.org/licenses>
 * @author  : Pascal SALAUN 
 * @Website : http://www.breizh-ltd.com <http://www.breizh-ltd.com>
 * ------------------------------------------------------------------------
 **/


/**
bmAPI is a Bluemind API Client.
Most of methods can be used in other applications. You've just modify somes.
Because bmStats do not modify any data of Blue Mind Services, ONLY GET AND POST METHODS ARE DEFINES AFTER.
So, if you want PUT and/or DELETE actions, you will add them yourself.
*/

class bmAPI {

	private $curl;
	private $jsonOrPhp = false ;

	/**
 	* init() 
	*
 	* init a curl handler 
 	*/
    public function init() {
   		$this->curl = curl_init();
    }

    /**
    * close()
    *
    * close a curl handler
    */
	public function close() {
		curl_close($this->curl);
	}

    /**
    * setOption()
    * 
	* args : (array) $options
    * 
	* set cURL handler options stored in associative as ie :
	*
	* array( CURLOPT_VERBOSE => FALSE )
    *
	* Have a look to http://php.net/manual/fr/function.curl-setopt.php for option details
    */
    public function setOption($options) {
	
		if (is_array($options) and !empty($options)) {
			curl_setopt_array($this->curl,$options); 	

       		} 
	}


    /**
    * setHeaderKey()
    *
    * args : (string) $token
    * 
    * set the TOKEN stored in header definition 'X-BM-ApiKey'
    */
	public function setHeaderKey($token) {
		$headers = ['Accept: application/json',
			    'Cache-Control: no-cache',
			    'X-BM-ApiKey: '.$token];

		curl_setopt($this->curl,CURLOPT_HTTPHEADER, $headers); 

	}


    /**
    * setURI()
    *
    * args : (string) $uri
    *
    * set the URI to the cURL handler
    */
	public function setURI($uri) {
		curl_setopt($this->curl,CURLOPT_URL, $uri);	
	}



    /**
    * post()
    *
    * args : (string) $data , (boolean) $jsonEncoded
    *
    * set the post data. If data is already json encoded, so $jsonEncoded will be 'true' (else 'false')
    */
	public function post($data, $jsonEncoded) {
		if ($jsonEncoded)
			$jdata = $data ;
		else
			$jdata = json_encode($data);	
		
	        curl_setopt($this->curl, CURLOPT_HTTPHEADER, array(
                                                        'Content-Type: application/json',
                                                        'Content-Length: ' . strlen($jdata)
                                                ));
        	curl_setopt($this->curl, CURLOPT_POST,true);
        	curl_setopt($this->curl, CURLOPT_POSTFIELDS, $jdata);
	
	}


    /**
    * setPhpResponse()
    *
    * store the json answer in php associative array
    */
	public function setPhpResponse() {

		$this->jsonOrPhp = true ;	

	} 
	
    /**
    * getResponse()
    *
    * return a json decoded answer
    */
    public function getResponse() {
		return json_decode(curl_exec($this->curl),$this->jsonOrPhp) ;

	}
}
?>
